==> SumsJob-0.1.0.tar.gz: SumsJob-0.1.0/README.md <==
# &Sigma;&Sigma;<sub>Job</sub>

&Sigma;&Sigma;<sub>Job</sub> or Sums<sub>Job</sub> (**S**imple **U**tility for **M**ultiple-**S**ervers **Job** **Sub**mission) is a simple Linux command-line utility which submits a job to one of the multiple servers each with limited resources. It will first look for servers with available resources, such as GPUs, and then run the job in that server interactively just as the job is running in your local machine.

**Tutorial**: [Slides](tutorials/sumsjob.pdf)

## Features

- Simple to use: one single `submit` command is all your need
- Automatically choose available GPUs among all the servers
- Display the output of the job in real time
- Kill the job by Ctrl-C
- Save the output in a log file
- Transfer back the files you specified

## Usage

### `$ gpuresource`

Show the status of GPUs on all servers.

### `$ submit jobfile jobname`

- `jobfile` : File to be run
- `jobname` : Job name, and also the folder name of the job

Options:

- `-h`, `--help` : Show this help message and exit
- `-i`, `--interact` : Submit as an interactive job
- `-s SERVER`, `--server SERVER` : Server host name
- `--gpuid GPUID` : GPU ID to be used; -1 to use CPU only

## Installation

Install [gpustat](https://github.com/wookayin/gpustat) in each server.

Then, you can install Sums<sub>Job</sub> with `pip`:

```
$ pip install sumsjob
```

You need to have a configuration file at `~/.sumsjob/config.py`. Use [config.py](sumsjob/config.py) as a template, and modify the values to your configurations.

- Make sure you can `ssh` to each server.
- Run `gpuresource` to check if everything works. Make sure `~/.local/bin` is in your `$PATH`.

## License

[GNU GPLv3](LICENSE)

==> SumsJob-0.1.1.tar.gz: SumsJob-0.1.1/README.md <==
# &Sigma;&Sigma;<sub>Job</sub>

[![PyPI version](https://badge.fury.io/py/SumsJob.svg)](https://badge.fury.io/py/SumsJob)
[![License](https://img.shields.io/github/license/lululxvi/sumsjob)](https://github.com/lululxvi/sumsjob/blob/master/LICENSE)

&Sigma;&Sigma;<sub>Job</sub> or Sums<sub>Job</sub> (**S**imple **U**tility for **M**ultiple-**S**ervers **Job** **Sub**mission) is a simple Linux command-line utility which submits a job to one of the multiple servers each with limited resources. It will first look for servers with available resources, such as GPUs, and then run the job in that server interactively just as the job is running in your local machine.

**Tutorial**: [Slides](https://github.com/lululxvi/sumsjob/blob/master/tutorials/sumsjob.pdf)

## Features

- Simple to use: one single `submit` command is all your need
- Automatically choose available GPUs among all the servers
- Display the output of the job in real time
- Kill the job by Ctrl-C
- Save the output in a log file
- Transfer back the files you specified

## Usage

### `$ gpuresource`

Show the status of GPUs on all servers.

### `$ submit jobfile jobname`

- `jobfile` : File to be run
- `jobname` : Job name, and also the folder name of the job. If not provided, a random number will be used.

Options:

- `-h`, `--help` : Show this help message and exit
- `-s SERVER`, `--server SERVER` : Server host name
- `--gpuid GPUID` : GPU ID to be used; -1 to use CPU only

## Installation

Install [gpustat](https://github.com/wookayin/gpustat) in each server.

Then, you can install Sums<sub>Job</sub> with `pip`:

```
$ pip install sumsjob
```

You need to have a configuration file at `~/.sumsjob/config.py`. Use [config.py](https://github.com/lululxvi/sumsjob/blob/master/sumsjob/config.py) as a template, and modify the values to your configurations.

- Make sure you can `ssh` to each server.
- Run `gpuresource` to check if everything works. Make sure `~/.local/bin` is in your `$PATH`.

## License

[GNU GPLv3](LICENSE)
